@@ -284,6 +284,13 @@ static Win32GLContext *currentGLContext;
     }
 }
 
+- (void *)CGLContextObj
+{
+  // FIXME: Until we have a wrapper library
+  // return the underlying context directly
+  return (void*)wgl_context;
+}
+
 - (void)clearDrawable
 {
   [self _detach];
@@ -327,7 +334,20 @@ static Win32GLContext *currentGLContext;
 }
 
 
-- (id)initWithFormat:(NSOpenGLPixelFormat *)aFormat 
+- (id)initWithCGLContextObj: (void *)context
+{
+  self = [super init];
+  if (!self)
+    {
+      return nil;
+    }
+  
+  // FIXME: Need to set the pixelFormat ivar
+  wgl_context = context;
+  return self;
+}
+
+- (id)initWithFormat:(NSOpenGLPixelFormat *)aFormat
 	shareContext:(NSOpenGLContext *)share
 {
   NSDebugMLLog(@"WGL", @"will init with format %@", aFormat);
