@@ -39,37 +39,45 @@
 #include <X11/Xlib.h>
 #include <math.h>
 
+#ifdef XRENDER
+#include <X11/extensions/Xrender.h>
+#endif
+
 @implementation XGGLPixelFormat
 
 + (int) glxMinorVersion
 {
-  Display * display = [(XGServer *)GSCurrentServer() xDisplay];
-  NSDictionary * attributes = [GSCurrentServer() attributes];
-  NSString * sn = [attributes objectForKey: GSScreenNumber];
+  static int cachedVersion = -1;
 
-  // This is due to some OpenGL drivers reporting a lower overall GLX version than they actually implement.
-  NSString * glxServerVersion = [NSString stringWithFormat:@"%s", glXQueryServerString(display, [sn intValue], GLX_VERSION)];
-  NSString * glxClientVersion = [NSString stringWithFormat:@"%s", glXGetClientString(display, GLX_VERSION)];
-
-  float serverversion = [glxServerVersion floatValue];
-  float clientversion = [glxClientVersion floatValue];
-
-  float serverIntegerPart;
-  float clientIntegerPart;
-  float fracServer = modff(serverversion, &serverIntegerPart);
-  float fracClient = modff(clientversion, &clientIntegerPart);
-
-  if ( serverIntegerPart == 1.0f && clientIntegerPart == 1.0f )
+  if (cachedVersion == -1)
     {
-      fracServer = rintf(fracServer * 10.0f);
-      fracClient = rintf(fracClient * 10.0f);
-
-      NSDebugMLLog(@"GLX", @"server %f client %f", fracServer, fracClient );
-
-      return (int)MIN(fracServer, fracClient);
+      Display * display = [(XGServer *)GSCurrentServer() xDisplay];
+      NSDictionary * attributes = [GSCurrentServer() attributes];
+      NSString * sn = [attributes objectForKey: GSScreenNumber];
+      
+      // This is due to some OpenGL drivers reporting a lower overall GLX version than they actually implement.
+      NSString *glxServerVersion = 
+        [NSString stringWithFormat:@"%s", glXQueryServerString(display, [sn intValue], GLX_VERSION)];
+      NSString *glxClientVersion =
+        [NSString stringWithFormat:@"%s", glXGetClientString(display, GLX_VERSION)];
+      float serverversion = [glxServerVersion floatValue];
+      float clientversion = [glxClientVersion floatValue];
+      float serverIntegerPart;
+      float clientIntegerPart;
+      float fracServer = modff(serverversion, &serverIntegerPart);
+      float fracClient = modff(clientversion, &clientIntegerPart);
+      
+      if ( serverIntegerPart == 1.0f && clientIntegerPart == 1.0f )
+        {
+          fracServer = rintf(fracServer * 10.0f);
+          fracClient = rintf(fracClient * 10.0f);
+          
+          NSDebugMLLog(@"GLX", @"server %f client %f", fracServer, fracClient);
+          cachedVersion = (int)MIN(fracServer, fracClient);
+        }
     }
 
-  return -1;
+  return cachedVersion;
 }
 
 // Works for some attributes only
@@ -82,10 +90,9 @@
   NSAssert((fbconfig != NULL || visualinfo != NULL) && configurationCount > 0,
             NSInternalInconsistencyException);
 
-
   if (glxminorversion >= 3)
     {
-      error = glXGetFBConfigAttrib(display, fbconfig[0], attrib, vals);
+      error = glXGetFBConfigAttrib(display, fbconfig[pickedFBConfig], attrib, vals);
       if ( error != 0 )
           NSDebugMLLog( @"GLX", @"Can not get FB attribute for pixel format %@ - Error %u",
                                 self, error );
@@ -104,6 +111,8 @@
   int AccumSize;
   NSOpenGLPixelFormatAttribute *ptr = pixelFormatAttributes;
   NSMutableData *data = [NSMutableData data];
+  
+  shouldRequestARGBVisual = NO;
 
 #define append(a, b) \
 do \
@@ -176,6 +185,8 @@ do \
             {
                 ptr++;
                 append(GLX_ALPHA_SIZE, *ptr);
+                if (*ptr > 0)
+                  shouldRequestARGBVisual = YES;
                 break;
             }
           case NSOpenGLPFADepthSize:
@@ -226,31 +237,31 @@ do \
             }
 
           case NSOpenGLPFAWindow:
-			{
+            {
               drawable_type |= GLX_WINDOW_BIT;
               break;
-			}
+            }
           case NSOpenGLPFAPixelBuffer:
-			{ 
+            { 
               drawable_type |= GLX_PBUFFER_BIT;
               break;
-			}
+            }
           case NSOpenGLPFAOffScreen:
-			{
+            {
               drawable_type |= GLX_PIXMAP_BIT;
               break;
-			}
+            }
 
           //can not be handled by X11
           case NSOpenGLPFAMinimumPolicy:
-			{
+            {
               break;
-			}
+            }
           // can not be handled by X11
           case NSOpenGLPFAMaximumPolicy:
-			{
+            {
               break;
-			}
+            }
           // Not supported, would be a lot of work to implement.
           case NSOpenGLPFAFullScreen:
             {
@@ -264,11 +275,9 @@ do \
                 {
                   ptr++;
                   append(GLX_SAMPLE_BUFFERS, *ptr);
-                  break;
                 }
-              #else
-              break;
               #endif
+              break;
             }
           case NSOpenGLPFASamples:
             {
@@ -277,11 +286,9 @@ do \
                 {
                   ptr++;
                   append(GLX_SAMPLES, *ptr);
-                  break;
                 }
-              #else
-              break;
               #endif
+              break;
             }
 
           case NSOpenGLPFAAuxDepthStencil:
@@ -302,7 +309,7 @@ do \
           case NSOpenGLPFASampleAlpha:
             break;
         }
-      ptr ++;
+      ptr++;
     }
 
   if ( drawable_type )
@@ -324,6 +331,10 @@ do \
   NSDictionary * dsattributes;
 
   self = [super init];
+  if (self == nil)
+    {
+      return nil;
+    }
 
   fbconfig = NULL;
   visualinfo = NULL;
@@ -344,7 +355,29 @@ do \
                         [glxAttributes mutableBytes],
                         &configurationCount);
 
-      visualinfo = glXGetVisualFromFBConfig(display,fbconfig[0]);
+      #if defined(XRENDER)
+      int i; 
+      for (i = 0; i < configurationCount; i++)
+        {
+          XVisualInfo * vinfo = glXGetVisualFromFBConfig(display, fbconfig[i]);
+          XRenderPictFormat* pictFormat = XRenderFindVisualFormat (display, vinfo->visual);
+	  if ((NULL != pictFormat
+               && (pictFormat->type == PictTypeDirect)
+               && (pictFormat->direct.alphaMask))
+              || !shouldRequestARGBVisual)
+	    {
+              pickedFBConfig = i;
+              visualinfo = vinfo;
+              break;
+            }
+        }
+      #endif
+
+      if (!visualinfo && configurationCount > 0)
+        {
+          visualinfo = glXGetVisualFromFBConfig(display,fbconfig[0]);
+          pickedFBConfig = 0;
+        }
     }
   else
     {
@@ -370,7 +403,7 @@ do \
 
 - (Display *) display
 {
-    return display;
+  return display;
 }
 
 - (XVisualInfo *) visualinfo
@@ -384,7 +417,7 @@ do \
 
   if (glxminorversion >= 3)
     {
-      context = glXCreateNewContext(display, fbconfig[0], 
+      context = glXCreateNewContext(display, fbconfig[pickedFBConfig], 
                                  GLX_RGBA_TYPE, [share glxcontext], YES);
     }
   else
@@ -396,8 +429,8 @@ do \
   if ( context == NULL )
     {
       NSDebugMLLog(@"GLX", 
-        @"Can not create GL context for pixel format %@ - Error %u",
-        self, glGetError());
+        @"Cannot create GL context for pixel format %@ - Error %s",
+        self, glGetString(glGetError()));
     }
 
   return context;
@@ -406,11 +439,11 @@ do \
 - (GLXWindow) drawableForWindow: (Window)xwindowid
 {
   GLXWindow win;
-  GLint error;
+  GLenum error;
 
   if (glxminorversion >= 3)
     {
-      win = glXCreateWindow(display, fbconfig[0], xwindowid, NULL);
+      win = glXCreateWindow(display, fbconfig[pickedFBConfig], xwindowid, NULL);
     }
   else
     {
@@ -421,8 +454,8 @@ do \
   if ( error != GL_NO_ERROR )
     {
       NSDebugMLLog(@"GLX", 
-                   @"Can not create GL window for pixel format %@ - Error %u",
-                   self, error );
+                   @"Cannot create GL window for pixel format %@ - Error %s",
+                   self, glGetString(error));
     }
 
   return win;
